import { TokenDelegateRole, MetadataDelegateRole } from '@metaplex-foundation/mpl-token-metadata';
import { DelegateRoleRequiredDataError } from './errors.mjs';
import { UnreachableCaseError } from '../../errors/SdkError.mjs';

const tokenDelegateRoleMap = {
  StandardV1: TokenDelegateRole.Standard,
  TransferV1: TokenDelegateRole.Transfer,
  LockedTransferV1: TokenDelegateRole.LockedTransfer,
  SaleV1: TokenDelegateRole.Sale,
  UtilityV1: TokenDelegateRole.Utility,
  StakingV1: TokenDelegateRole.Staking
};
const metadataDelegateRoleMap = {
  // AuthorityV1: MetadataDelegateRole.Authority,
  CollectionV1: MetadataDelegateRole.Collection,
  // UseV1: MetadataDelegateRole.Use,
  UpdateV1: MetadataDelegateRole.Update,
  ProgrammableConfigV1: MetadataDelegateRole.ProgrammableConfig
};
const metadataDelegateSeedMap = {
  [MetadataDelegateRole.Authority]: 'authority_delegate',
  [MetadataDelegateRole.Collection]: 'collection_delegate',
  [MetadataDelegateRole.Use]: 'use_delegate',
  [MetadataDelegateRole.Update]: 'update_delegate',
  [MetadataDelegateRole.ProgrammableConfig]: 'programmable_config_delegate'
};
const delegateCustomDataMap = {
  // Metadata.
  // AuthorityV1: false,
  CollectionV1: false,
  // UseV1: false,
  UpdateV1: false,
  ProgrammableConfigV1: false,
  // Token
  StandardV1: true,
  TransferV1: true,
  SaleV1: true,
  UtilityV1: true,
  StakingV1: true,
  LockedTransferV1: true
};
const getTokenDelegateRole = type => {
  const role = tokenDelegateRoleMap[type];
  if (!role) throw new UnreachableCaseError(type);
  return role;
};
const getMetadataDelegateRole = type => {
  const role = metadataDelegateRoleMap[type];
  if (!role) throw new UnreachableCaseError(type);
  return role;
};
const getMetadataDelegateRoleSeed = type => {
  return metadataDelegateSeedMap[getMetadataDelegateRole(type)];
};
const getDefaultDelegateArgs = type => {
  const hasCustomData = delegateCustomDataMap[type];
  if (hasCustomData === undefined) throw new UnreachableCaseError(type);
  if (hasCustomData) throw new DelegateRoleRequiredDataError(type);
  return {
    __kind: type
  };
};

export { getDefaultDelegateArgs, getMetadataDelegateRole, getMetadataDelegateRoleSeed, getTokenDelegateRole };
//# sourceMappingURL=DelegateType.mjs.map
