import { PublicKey } from '../../../types';
/**
 * The programGate guard restricts the programs that can be invoked within
 * the mint transaction. It allows the necessary programs for the mint
 * instruction to work and any other program specified in the configuration.
 *
 * This object defines the settings that should be
 * provided when creating and/or updating a Candy
 * Machine if you wish to enable this guard.
 */
export type ProgramGateGuardSettings = {
    /**
     * An array of additional programs that can be invoked in a mint transaction.
     *
     * These programs are in addition to the mandatory programs that
     * are required for the mint instruction to work. Providing an empty
     * array is equivalent to only authorising the mandatory programs.
     *
     * The mandatory programs are:
     * - Candy Machine
     * - System Program
     * - SPL Token
     * - SPL ASsociated Token Account
     */
    additional: PublicKey[];
};
